diff --git a/app/Console/Commands/Environment/AppSettingsCommand.php b/app/Console/Commands/Environment/AppSettingsCommand.php
index 17c2b5bb..05aa2028 100644
--- a/app/Console/Commands/Environment/AppSettingsCommand.php
+++ b/app/Console/Commands/Environment/AppSettingsCommand.php
@@ -58,7 +58,7 @@ class AppSettingsCommand extends Command
      * @var string
      */
     protected $signature = 'p:environment:setup
-                            {--new-salt : Wether or not to generate a new salt for Hashids.}
+                            {--new-salt : Whether or not to generate a new salt for Hashids.}
                             {--author= : The email that services created on this instance should be linked to.}
                             {--url= : The URL that this Panel is running on.}
                             {--timezone= : The timezone to use for Panel times.}
diff --git a/app/Console/Commands/InfoCommand.php b/app/Console/Commands/InfoCommand.php
index 699adee1..d8544477 100644
--- a/app/Console/Commands/InfoCommand.php
+++ b/app/Console/Commands/InfoCommand.php
@@ -84,7 +84,7 @@ class InfoCommand extends Command
             ['Host', $this->config->get("database.connections.{$driver}.host")],
             ['Port', $this->config->get("database.connections.{$driver}.port")],
             ['Database', $this->config->get("database.connections.{$driver}.database")],
-            ['Usernamne', $this->config->get("database.connections.{$driver}.username")],
+            ['Username', $this->config->get("database.connections.{$driver}.username")],
         ], 'compact');
 
         $this->output->title('Email Configuration');
diff --git a/app/Console/Commands/Server/BulkPowerActionCommand.php b/app/Console/Commands/Server/BulkPowerActionCommand.php
index ced90db8..91e761e6 100644
--- a/app/Console/Commands/Server/BulkPowerActionCommand.php
+++ b/app/Console/Commands/Server/BulkPowerActionCommand.php
@@ -31,8 +31,8 @@ class BulkPowerActionCommand extends Command
      */
     protected $signature = 'p:server:bulk-power
                             {action : The action to perform (start, stop, restart, kill)}
-                            {--servers= : A comma seperated list of servers.}
-                            {--nodes= : A comma seperated list of nodes.}';
+                            {--servers= : A comma separated list of servers.}
+                            {--nodes= : A comma separated list of nodes.}';
 
     /**
      * @var string
diff --git a/app/Contracts/Repository/AllocationRepositoryInterface.php b/app/Contracts/Repository/AllocationRepositoryInterface.php
index 1331e906..994ded2c 100644
--- a/app/Contracts/Repository/AllocationRepositoryInterface.php
+++ b/app/Contracts/Repository/AllocationRepositoryInterface.php
@@ -59,7 +59,7 @@ interface AllocationRepositoryInterface extends RepositoryInterface
     public function getAssignedAllocationIds(int $server): array;
 
     /**
-     * Return a concated result set of node ips that already have at least one
+     * Return a concatenated result set of node ips that already have at least one
      * server assigned to that IP. This allows for filtering out sets for
      * dedicated allocation IPs.
      *
diff --git a/app/Contracts/Repository/Daemon/ServerRepositoryInterface.php b/app/Contracts/Repository/Daemon/ServerRepositoryInterface.php
index a00686a0..d640c1c0 100644
--- a/app/Contracts/Repository/Daemon/ServerRepositoryInterface.php
+++ b/app/Contracts/Repository/Daemon/ServerRepositoryInterface.php
@@ -62,7 +62,7 @@ interface ServerRepositoryInterface extends BaseRepositoryInterface
     public function delete(): ResponseInterface;
 
     /**
-     * Return detials on a specific server.
+     * Return details on a specific server.
      *
      * @return \Psr\Http\Message\ResponseInterface
      */
diff --git a/app/Contracts/Repository/DatabaseRepositoryInterface.php b/app/Contracts/Repository/DatabaseRepositoryInterface.php
index f5d53151..e04c5a86 100644
--- a/app/Contracts/Repository/DatabaseRepositoryInterface.php
+++ b/app/Contracts/Repository/DatabaseRepositoryInterface.php
@@ -19,7 +19,7 @@ interface DatabaseRepositoryInterface extends RepositoryInterface
     public function setConnection(string $connection);
 
     /**
-     * Return the connection to execute statements aganist.
+     * Return the connection to execute statements against.
      *
      * @return string
      */
diff --git a/app/Contracts/Repository/EggRepositoryInterface.php b/app/Contracts/Repository/EggRepositoryInterface.php
index 364fd0c6..2d018eb6 100644
--- a/app/Contracts/Repository/EggRepositoryInterface.php
+++ b/app/Contracts/Repository/EggRepositoryInterface.php
@@ -57,5 +57,5 @@ interface EggRepositoryInterface extends RepositoryInterface
      * @param int $service
      * @return bool
      */
-    public function isCopiableScript(int $copyFromId, int $service): bool;
+    public function isCopyableScript(int $copyFromId, int $service): bool;
 }
diff --git a/app/Contracts/Repository/RepositoryInterface.php b/app/Contracts/Repository/RepositoryInterface.php
index 4a098c34..c6f5b7b1 100644
--- a/app/Contracts/Repository/RepositoryInterface.php
+++ b/app/Contracts/Repository/RepositoryInterface.php
@@ -29,7 +29,7 @@ interface RepositoryInterface
     public function getBuilder();
 
     /**
-     * Returns the colummns to be selected or returned by the query.
+     * Returns the columns to be selected or returned by the query.
      *
      * @return mixed
      */
@@ -59,7 +59,7 @@ interface RepositoryInterface
     public function withFreshModel();
 
     /**
-     * Set wether or not the repository should return a fresh model
+     * Set whether or not the repository should return a fresh model
      * when changes are committed.
      *
      * @param bool $fresh
diff --git a/app/Contracts/Repository/ServerRepositoryInterface.php b/app/Contracts/Repository/ServerRepositoryInterface.php
index dc677fba..c949b760 100644
--- a/app/Contracts/Repository/ServerRepositoryInterface.php
+++ b/app/Contracts/Repository/ServerRepositoryInterface.php
@@ -119,7 +119,7 @@ interface ServerRepositoryInterface extends RepositoryInterface, SearchableInter
     public function getByUuid(string $uuid): Server;
 
     /**
-     * Return all of the servers that should have a power action performed aganist them.
+     * Return all of the servers that should have a power action performed against them.
      *
      * @param int[] $servers
      * @param int[] $nodes
diff --git a/app/Http/Controllers/API/Remote/EggRetrievalController.php b/app/Http/Controllers/API/Remote/EggRetrievalController.php
index b98a14f3..2f006b64 100644
--- a/app/Http/Controllers/API/Remote/EggRetrievalController.php
+++ b/app/Http/Controllers/API/Remote/EggRetrievalController.php
@@ -41,7 +41,7 @@ class EggRetrievalController extends Controller
     }
 
     /**
-     * Return a JSON array of Eggs and the SHA1 hash of thier configuration file.
+     * Return a JSON array of Eggs and the SHA1 hash of their configuration file.
      *
      * @return \Illuminate\Http\JsonResponse
      */
diff --git a/app/Http/Controllers/Base/SecurityController.php b/app/Http/Controllers/Base/SecurityController.php
index 583d8361..3bb85a0b 100644
--- a/app/Http/Controllers/Base/SecurityController.php
+++ b/app/Http/Controllers/Base/SecurityController.php
@@ -96,7 +96,7 @@ class SecurityController extends Controller
     }
 
     /**
-     * Verifies that 2FA token recieved is valid and will work on the account.
+     * Verifies that 2FA token received is valid and will work on the account.
      *
      * @param \Illuminate\Http\Request $request
      * @return \Illuminate\Http\Response
diff --git a/app/Http/Kernel.php b/app/Http/Kernel.php
index b6d44530..72158193 100644
--- a/app/Http/Kernel.php
+++ b/app/Http/Kernel.php
@@ -111,7 +111,7 @@ class Kernel extends HttpKernel
 
         // Server specific middleware (used for authenticating access to resources)
         //
-        // These are only used for individual server authentication, and not gloabl
+        // These are only used for individual server authentication, and not global
         // actions from other resources. They are defined in the route files.
         'server..database' => DatabaseBelongsToServer::class,
         'server..subuser' => SubuserBelongsToServer::class,
diff --git a/app/Http/Middleware/Api/Application/AuthenticateApplicationUser.php b/app/Http/Middleware/Api/Application/AuthenticateApplicationUser.php
index 48da8a74..ddcd2948 100644
--- a/app/Http/Middleware/Api/Application/AuthenticateApplicationUser.php
+++ b/app/Http/Middleware/Api/Application/AuthenticateApplicationUser.php
@@ -10,7 +10,7 @@ class AuthenticateApplicationUser
 {
     /**
      * Authenticate that the currently authenticated user is an administrator
-     * and should be allowed to proceede through the application API.
+     * and should be allowed to proceed through the application API.
      *
      * @param \Illuminate\Http\Request $request
      * @param \Closure                 $next
diff --git a/app/Http/Middleware/RequireTwoFactorAuthentication.php b/app/Http/Middleware/RequireTwoFactorAuthentication.php
index 26698347..aee1cf06 100644
--- a/app/Http/Middleware/RequireTwoFactorAuthentication.php
+++ b/app/Http/Middleware/RequireTwoFactorAuthentication.php
@@ -25,7 +25,7 @@ class RequireTwoFactorAuthentication
     private $alert;
 
     /**
-     * The names of routes that should be accessable without 2FA enabled.
+     * The names of routes that should be accessible without 2FA enabled.
      *
      * @var array
      */
diff --git a/app/Http/Middleware/Server/AuthenticateAsSubuser.php b/app/Http/Middleware/Server/AuthenticateAsSubuser.php
index 1a185bb6..ebf9cd62 100644
--- a/app/Http/Middleware/Server/AuthenticateAsSubuser.php
+++ b/app/Http/Middleware/Server/AuthenticateAsSubuser.php
@@ -33,7 +33,7 @@ class AuthenticateAsSubuser
     }
 
     /**
-     * Determine if a subuser has permissions to access a server, if so set thier access token.
+     * Determine if a subuser has permissions to access a server, if so set their access token.
      *
      * @param \Illuminate\Http\Request $request
      * @param \Closure                 $next
diff --git a/app/Http/Requests/Admin/Api/StoreApplicationApiKeyRequest.php b/app/Http/Requests/Admin/Api/StoreApplicationApiKeyRequest.php
index 372dd115..643e9a1d 100644
--- a/app/Http/Requests/Admin/Api/StoreApplicationApiKeyRequest.php
+++ b/app/Http/Requests/Admin/Api/StoreApplicationApiKeyRequest.php
@@ -16,7 +16,7 @@ class StoreApplicationApiKeyRequest extends AdminFormRequest
         $modelRules = ApiKey::getCreateRules();
 
         return collect(AdminAcl::getResourceList())->mapWithKeys(function ($resource) use ($modelRules) {
-            return [AdminAcl::COLUMN_IDENTIFER . $resource => $modelRules['r_' . $resource]];
+            return [AdminAcl::COLUMN_IDENTIFIER . $resource => $modelRules['r_' . $resource]];
         })->merge(['memo' => $modelRules['memo']])->toArray();
     }
 
@@ -33,7 +33,7 @@ class StoreApplicationApiKeyRequest extends AdminFormRequest
     public function getKeyPermissions(): array
     {
         return collect($this->validated())->filter(function ($value, $key) {
-            return substr($key, 0, strlen(AdminAcl::COLUMN_IDENTIFER)) === AdminAcl::COLUMN_IDENTIFER;
+            return substr($key, 0, strlen(AdminAcl::COLUMN_IDENTIFIER)) === AdminAcl::COLUMN_IDENTIFIER;
         })->toArray();
     }
 }
diff --git a/app/Http/Requests/Admin/Settings/MailSettingsFormRequest.php b/app/Http/Requests/Admin/Settings/MailSettingsFormRequest.php
index 5a2e2ee8..92a23272 100644
--- a/app/Http/Requests/Admin/Settings/MailSettingsFormRequest.php
+++ b/app/Http/Requests/Admin/Settings/MailSettingsFormRequest.php
@@ -8,7 +8,7 @@ use Pterodactyl\Http\Requests\Admin\AdminFormRequest;
 class MailSettingsFormRequest extends AdminFormRequest
 {
     /**
-     * Return rules to validate mail settings POST data aganist.
+     * Return rules to validate mail settings POST data against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Api/Application/ApplicationApiRequest.php b/app/Http/Requests/Api/Application/ApplicationApiRequest.php
index 084a89bd..ca5f40dd 100644
--- a/app/Http/Requests/Api/Application/ApplicationApiRequest.php
+++ b/app/Http/Requests/Api/Application/ApplicationApiRequest.php
@@ -38,7 +38,7 @@ abstract class ApplicationApiRequest extends FormRequest
 
     /**
      * Determine if the current user is authorized to perform
-     * the requested action aganist the API.
+     * the requested action against the API.
      *
      * @return bool
      *
diff --git a/app/Http/Requests/Api/Application/Locations/StoreLocationRequest.php b/app/Http/Requests/Api/Application/Locations/StoreLocationRequest.php
index 5a71883a..317b6c54 100644
--- a/app/Http/Requests/Api/Application/Locations/StoreLocationRequest.php
+++ b/app/Http/Requests/Api/Application/Locations/StoreLocationRequest.php
@@ -19,7 +19,7 @@ class StoreLocationRequest extends ApplicationApiRequest
     protected $permission = AdminAcl::WRITE;
 
     /**
-     * Rules to validate the request aganist.
+     * Rules to validate the request against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Api/Application/Locations/UpdateLocationRequest.php b/app/Http/Requests/Api/Application/Locations/UpdateLocationRequest.php
index c65a6f90..b29c1c33 100644
--- a/app/Http/Requests/Api/Application/Locations/UpdateLocationRequest.php
+++ b/app/Http/Requests/Api/Application/Locations/UpdateLocationRequest.php
@@ -20,7 +20,7 @@ class UpdateLocationRequest extends StoreLocationRequest
     }
 
     /**
-     * Rules to validate this request aganist.
+     * Rules to validate this request against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Api/Application/Servers/UpdateServerBuildConfigurationRequest.php b/app/Http/Requests/Api/Application/Servers/UpdateServerBuildConfigurationRequest.php
index 076abdf4..d3d4a8b2 100644
--- a/app/Http/Requests/Api/Application/Servers/UpdateServerBuildConfigurationRequest.php
+++ b/app/Http/Requests/Api/Application/Servers/UpdateServerBuildConfigurationRequest.php
@@ -7,7 +7,7 @@ use Pterodactyl\Models\Server;
 class UpdateServerBuildConfigurationRequest extends ServerWriteRequest
 {
     /**
-     * Return the rules to validate this request aganist.
+     * Return the rules to validate this request against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Api/Application/Servers/UpdateServerStartupRequest.php b/app/Http/Requests/Api/Application/Servers/UpdateServerStartupRequest.php
index d337cb4d..acb6043c 100644
--- a/app/Http/Requests/Api/Application/Servers/UpdateServerStartupRequest.php
+++ b/app/Http/Requests/Api/Application/Servers/UpdateServerStartupRequest.php
@@ -19,7 +19,7 @@ class UpdateServerStartupRequest extends ApplicationApiRequest
     protected $permission = AdminAcl::WRITE;
 
     /**
-     * Validation rules to run the input aganist.
+     * Validation rules to run the input against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Api/Client/ClientApiRequest.php b/app/Http/Requests/Api/Client/ClientApiRequest.php
index ed63ccbf..92402e51 100644
--- a/app/Http/Requests/Api/Client/ClientApiRequest.php
+++ b/app/Http/Requests/Api/Client/ClientApiRequest.php
@@ -8,7 +8,7 @@ abstract class ClientApiRequest extends ApplicationApiRequest
 {
     /**
      * Determine if the current user is authorized to perform
-     * the requested action aganist the API.
+     * the requested action against the API.
      *
      * @return bool
      */
diff --git a/app/Http/Requests/Api/Client/Servers/SendCommandRequest.php b/app/Http/Requests/Api/Client/Servers/SendCommandRequest.php
index 788f9773..22feb2af 100644
--- a/app/Http/Requests/Api/Client/Servers/SendCommandRequest.php
+++ b/app/Http/Requests/Api/Client/Servers/SendCommandRequest.php
@@ -17,7 +17,7 @@ class SendCommandRequest extends GetServerRequest
     }
 
     /**
-     * Rules to validate this request aganist.
+     * Rules to validate this request against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Api/Client/Servers/SendPowerRequest.php b/app/Http/Requests/Api/Client/Servers/SendPowerRequest.php
index 19614d18..7a32c117 100644
--- a/app/Http/Requests/Api/Client/Servers/SendPowerRequest.php
+++ b/app/Http/Requests/Api/Client/Servers/SendPowerRequest.php
@@ -18,7 +18,7 @@ class SendPowerRequest extends ClientApiRequest
     }
 
     /**
-     * Rules to validate this request aganist.
+     * Rules to validate this request against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Base/StoreAccountKeyRequest.php b/app/Http/Requests/Base/StoreAccountKeyRequest.php
index ab390663..2cfc2278 100644
--- a/app/Http/Requests/Base/StoreAccountKeyRequest.php
+++ b/app/Http/Requests/Base/StoreAccountKeyRequest.php
@@ -7,7 +7,7 @@ use Pterodactyl\Http\Requests\FrontendUserFormRequest;
 class StoreAccountKeyRequest extends FrontendUserFormRequest
 {
     /**
-     * Rules to validate the request input aganist before storing
+     * Rules to validate the request input against before storing
      * an account API key.
      *
      * @return array
diff --git a/app/Http/Requests/Server/Database/DeleteServerDatabaseRequest.php b/app/Http/Requests/Server/Database/DeleteServerDatabaseRequest.php
index f2c81d9c..eed54e2e 100644
--- a/app/Http/Requests/Server/Database/DeleteServerDatabaseRequest.php
+++ b/app/Http/Requests/Server/Database/DeleteServerDatabaseRequest.php
@@ -19,7 +19,7 @@ class DeleteServerDatabaseRequest extends ServerFormRequest
     }
 
     /**
-     * Return the user permission to validate this request aganist.
+     * Return the user permission to validate this request against.
      *
      * @return string
      */
@@ -29,7 +29,7 @@ class DeleteServerDatabaseRequest extends ServerFormRequest
     }
 
     /**
-     * Rules to validate this request aganist.
+     * Rules to validate this request against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Server/Database/StoreServerDatabaseRequest.php b/app/Http/Requests/Server/Database/StoreServerDatabaseRequest.php
index 2af23a91..1c2fe4af 100644
--- a/app/Http/Requests/Server/Database/StoreServerDatabaseRequest.php
+++ b/app/Http/Requests/Server/Database/StoreServerDatabaseRequest.php
@@ -19,7 +19,7 @@ class StoreServerDatabaseRequest extends ServerFormRequest
     }
 
     /**
-     * Return the user permission to validate this request aganist.
+     * Return the user permission to validate this request against.
      *
      * @return string
      */
@@ -29,7 +29,7 @@ class StoreServerDatabaseRequest extends ServerFormRequest
     }
 
     /**
-     * Rules to validate this request aganist.
+     * Rules to validate this request against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Server/ScheduleCreationFormRequest.php b/app/Http/Requests/Server/ScheduleCreationFormRequest.php
index a90dd749..6291d3cb 100644
--- a/app/Http/Requests/Server/ScheduleCreationFormRequest.php
+++ b/app/Http/Requests/Server/ScheduleCreationFormRequest.php
@@ -12,7 +12,7 @@ namespace Pterodactyl\Http\Requests\Server;
 class ScheduleCreationFormRequest extends ServerFormRequest
 {
     /**
-     * Permission to validate this request aganist.
+     * Permission to validate this request against.
      *
      * @return string
      */
diff --git a/app/Http/Requests/Server/ServerFormRequest.php b/app/Http/Requests/Server/ServerFormRequest.php
index f59ea3ae..c0ca370b 100644
--- a/app/Http/Requests/Server/ServerFormRequest.php
+++ b/app/Http/Requests/Server/ServerFormRequest.php
@@ -8,7 +8,7 @@ use Pterodactyl\Http\Requests\FrontendUserFormRequest;
 abstract class ServerFormRequest extends FrontendUserFormRequest
 {
     /**
-     * Return the user permission to validate this request aganist.
+     * Return the user permission to validate this request against.
      *
      * @return string
      */
diff --git a/app/Http/Requests/Server/Subuser/SubuserStoreFormRequest.php b/app/Http/Requests/Server/Subuser/SubuserStoreFormRequest.php
index 861732e8..0ada0167 100644
--- a/app/Http/Requests/Server/Subuser/SubuserStoreFormRequest.php
+++ b/app/Http/Requests/Server/Subuser/SubuserStoreFormRequest.php
@@ -7,7 +7,7 @@ use Pterodactyl\Http\Requests\Server\ServerFormRequest;
 class SubuserStoreFormRequest extends ServerFormRequest
 {
     /**
-     * Return the user permission to validate this request aganist.
+     * Return the user permission to validate this request against.
      *
      * @return string
      */
@@ -17,7 +17,7 @@ class SubuserStoreFormRequest extends ServerFormRequest
     }
 
     /**
-     * The rules to validate this request submission aganist.
+     * The rules to validate this request submission against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Server/Subuser/SubuserUpdateFormRequest.php b/app/Http/Requests/Server/Subuser/SubuserUpdateFormRequest.php
index 284b8755..7ff82abc 100644
--- a/app/Http/Requests/Server/Subuser/SubuserUpdateFormRequest.php
+++ b/app/Http/Requests/Server/Subuser/SubuserUpdateFormRequest.php
@@ -7,7 +7,7 @@ use Pterodactyl\Http\Requests\Server\ServerFormRequest;
 class SubuserUpdateFormRequest extends ServerFormRequest
 {
     /**
-     * Return the user permission to validate this request aganist.
+     * Return the user permission to validate this request against.
      *
      * @return string
      */
@@ -17,7 +17,7 @@ class SubuserUpdateFormRequest extends ServerFormRequest
     }
 
     /**
-     * The rules to validate this request submission aganist.
+     * The rules to validate this request submission against.
      *
      * @return array
      */
diff --git a/app/Http/Requests/Server/UpdateFileContentsFormRequest.php b/app/Http/Requests/Server/UpdateFileContentsFormRequest.php
index 0ebaa25b..7ded39bc 100644
--- a/app/Http/Requests/Server/UpdateFileContentsFormRequest.php
+++ b/app/Http/Requests/Server/UpdateFileContentsFormRequest.php
@@ -20,7 +20,7 @@ use Pterodactyl\Exceptions\Http\Connection\DaemonConnectionException;
 class UpdateFileContentsFormRequest extends ServerFormRequest
 {
     /**
-     * Return the permission string to validate this request aganist.
+     * Return the permission string to validate this request against.
      *
      * @return string
      */
diff --git a/app/Jobs/Schedule/RunTaskJob.php b/app/Jobs/Schedule/RunTaskJob.php
index a00052b1..a7fd8486 100644
--- a/app/Jobs/Schedule/RunTaskJob.php
+++ b/app/Jobs/Schedule/RunTaskJob.php
@@ -92,7 +92,7 @@ class RunTaskJob extends Job implements ShouldQueue
             return;
         }
 
-        // Perform the provided task aganist the daemon.
+        // Perform the provided task against the daemon.
         switch ($task->action) {
             case 'power':
                 $this->powerRepository->setServer($server)
diff --git a/app/Models/ApiKey.php b/app/Models/ApiKey.php
index bd05454d..797522c3 100644
--- a/app/Models/ApiKey.php
+++ b/app/Models/ApiKey.php
@@ -95,7 +95,7 @@ class ApiKey extends Model implements CleansAttributes, ValidableContract
     ];
 
     /**
-     * Rules to protect aganist invalid data entry to DB.
+     * Rules to protect against invalid data entry to DB.
      *
      * @var array
      */
diff --git a/app/Models/DatabaseHost.php b/app/Models/DatabaseHost.php
index f42f2650..c564f725 100644
--- a/app/Models/DatabaseHost.php
+++ b/app/Models/DatabaseHost.php
@@ -90,7 +90,7 @@ class DatabaseHost extends Model implements CleansAttributes, ValidableContract
     }
 
     /**
-     * Gets the databases assocaited with this host.
+     * Gets the databases associated with this host.
      *
      * @return \Illuminate\Database\Eloquent\Relations\HasMany
      */
diff --git a/app/Models/Location.php b/app/Models/Location.php
index c680a54d..10fff147 100644
--- a/app/Models/Location.php
+++ b/app/Models/Location.php
@@ -53,7 +53,7 @@ class Location extends Model implements CleansAttributes, ValidableContract
     ];
 
     /**
-     * Gets the nodes in a specificed location.
+     * Gets the nodes in a specified location.
      *
      * @return \Illuminate\Database\Eloquent\Relations\HasMany
      */
diff --git a/app/Models/User.php b/app/Models/User.php
index aff4f328..6732b23a 100644
--- a/app/Models/User.php
+++ b/app/Models/User.php
@@ -188,7 +188,7 @@ class User extends Model implements
     }
 
     /**
-     * Store the username as a lowecase string.
+     * Store the username as a lowercase string.
      *
      * @param string $value
      */
@@ -198,7 +198,7 @@ class User extends Model implements
     }
 
     /**
-     * Return a concated result for the accounts full name.
+     * Return a concatenated result for the accounts full name.
      *
      * @return string
      */
diff --git a/app/Providers/HashidsServiceProvider.php b/app/Providers/HashidsServiceProvider.php
index ae16d875..f2b3935d 100644
--- a/app/Providers/HashidsServiceProvider.php
+++ b/app/Providers/HashidsServiceProvider.php
@@ -27,7 +27,7 @@ class HashidsServiceProvider extends ServiceProvider
             return new Hashids(
                 $config->get('hashids.salt', ''),
                 $config->get('hashids.length', 0),
-                $config->get('hashids.alphabet', 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890')
+                $config->get('hashids.alphabet', 'abcdefghijkmlnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890')
             );
         });
 
diff --git a/app/Repositories/Daemon/ServerRepository.php b/app/Repositories/Daemon/ServerRepository.php
index cf5a5a69..f26ef104 100644
--- a/app/Repositories/Daemon/ServerRepository.php
+++ b/app/Repositories/Daemon/ServerRepository.php
@@ -95,7 +95,7 @@ class ServerRepository extends BaseRepository implements ServerRepositoryInterfa
     }
 
     /**
-     * Return detials on a specific server.
+     * Return details on a specific server.
      *
      * @return \Psr\Http\Message\ResponseInterface
      */
diff --git a/app/Repositories/Eloquent/AllocationRepository.php b/app/Repositories/Eloquent/AllocationRepository.php
index a47134e4..a9721ac0 100644
--- a/app/Repositories/Eloquent/AllocationRepository.php
+++ b/app/Repositories/Eloquent/AllocationRepository.php
@@ -97,7 +97,7 @@ class AllocationRepository extends EloquentRepository implements AllocationRepos
     }
 
     /**
-     * Return a concated result set of node ips that already have at least one
+     * Return a concatenated result set of node ips that already have at least one
      * server assigned to that IP. This allows for filtering out sets for
      * dedicated allocation IPs.
      *
diff --git a/app/Repositories/Eloquent/DatabaseRepository.php b/app/Repositories/Eloquent/DatabaseRepository.php
index 8a8c93fd..d3b615b9 100644
--- a/app/Repositories/Eloquent/DatabaseRepository.php
+++ b/app/Repositories/Eloquent/DatabaseRepository.php
@@ -59,7 +59,7 @@ class DatabaseRepository extends EloquentRepository implements DatabaseRepositor
     }
 
     /**
-     * Return the connection to execute statements aganist.
+     * Return the connection to execute statements against.
      *
      * @return string
      */
diff --git a/app/Repositories/Eloquent/EggRepository.php b/app/Repositories/Eloquent/EggRepository.php
index 10d27f28..a3a96efb 100644
--- a/app/Repositories/Eloquent/EggRepository.php
+++ b/app/Repositories/Eloquent/EggRepository.php
@@ -92,7 +92,7 @@ class EggRepository extends EloquentRepository implements EggRepositoryInterface
      * @param int $service
      * @return bool
      */
-    public function isCopiableScript(int $copyFromId, int $service): bool
+    public function isCopyableScript(int $copyFromId, int $service): bool
     {
         return $this->getBuilder()->whereNull('copy_script_from')
             ->where('id', '=', $copyFromId)
diff --git a/app/Repositories/Eloquent/ServerRepository.php b/app/Repositories/Eloquent/ServerRepository.php
index 2fc5f878..90c2601e 100644
--- a/app/Repositories/Eloquent/ServerRepository.php
+++ b/app/Repositories/Eloquent/ServerRepository.php
@@ -265,7 +265,7 @@ class ServerRepository extends EloquentRepository implements ServerRepositoryInt
     }
 
     /**
-     * Return all of the servers that should have a power action performed aganist them.
+     * Return all of the servers that should have a power action performed against them.
      *
      * @param int[] $servers
      * @param int[] $nodes
diff --git a/app/Repositories/Repository.php b/app/Repositories/Repository.php
index c3014a31..c209e33b 100644
--- a/app/Repositories/Repository.php
+++ b/app/Repositories/Repository.php
@@ -37,7 +37,7 @@ abstract class Repository implements RepositoryInterface
     {
         $this->app = $application;
 
-        $this->initalizeModel($this->model());
+        $this->initializeModel($this->model());
     }
 
     /**
@@ -103,7 +103,7 @@ abstract class Repository implements RepositoryInterface
     }
 
     /**
-     * Set wether or not the repository should return a fresh model
+     * Set whether or not the repository should return a fresh model
      * when changes are committed.
      *
      * @param bool $fresh
@@ -123,7 +123,7 @@ abstract class Repository implements RepositoryInterface
      * @param array $model
      * @return mixed
      */
-    protected function initalizeModel(...$model)
+    protected function initializeModel(...$model)
     {
         switch (count($model)) {
             case 1:
@@ -131,7 +131,7 @@ abstract class Repository implements RepositoryInterface
             case 2:
                 return $this->model = call_user_func([$this->app->make($model[0]), $model[1]]);
             default:
-                throw new InvalidArgumentException('Model must be a FQCN or an array with a count of two.');
+                throw new InvalidArgumentException('Model must be a FQDN or an array with a count of two.');
         }
     }
 }
diff --git a/app/Services/Acl/Api/AdminAcl.php b/app/Services/Acl/Api/AdminAcl.php
index 54bd594f..fd22dfb6 100644
--- a/app/Services/Acl/Api/AdminAcl.php
+++ b/app/Services/Acl/Api/AdminAcl.php
@@ -9,9 +9,9 @@ class AdminAcl
 {
     /**
      * Resource permission columns in the api_keys table begin
-     * with this identifer.
+     * with this identifier.
      */
-    const COLUMN_IDENTIFER = 'r_';
+    const COLUMN_IDENTIFIER = 'r_';
 
     /**
      * The different types of permissions available for API keys. This
@@ -63,7 +63,7 @@ class AdminAcl
      */
     public static function check(ApiKey $key, string $resource, int $action = self::READ)
     {
-        return self::can(data_get($key, self::COLUMN_IDENTIFER . $resource, self::NONE), $action);
+        return self::can(data_get($key, self::COLUMN_IDENTIFIER . $resource, self::NONE), $action);
     }
 
     /**
diff --git a/app/Services/Api/KeyCreationService.php b/app/Services/Api/KeyCreationService.php
index 4a8efe7b..b5143162 100644
--- a/app/Services/Api/KeyCreationService.php
+++ b/app/Services/Api/KeyCreationService.php
@@ -51,7 +51,7 @@ class KeyCreationService
 
     /**
      * Create a new API key for the Panel using the permissions passed in the data request.
-     * This will automatically generate an identifer and an encrypted token that are
+     * This will automatically generate an identifier and an encrypted token that are
      * stored in the database.
      *
      * @param array $data
diff --git a/app/Services/Deployment/FindViableNodesService.php b/app/Services/Deployment/FindViableNodesService.php
index 973d7fc7..6d6832c2 100644
--- a/app/Services/Deployment/FindViableNodesService.php
+++ b/app/Services/Deployment/FindViableNodesService.php
@@ -88,7 +88,7 @@ class FindViableNodesService
      * attempt to find all nodes in the defined locations that meet the disk and
      * memory availability requirements. Any nodes not meeting those requirements
      * are tossed out, as are any nodes marked as non-public, meaning automatic
-     * deployments should not be done aganist them.
+     * deployments should not be done against them.
      *
      * @return int[]
      * @throws \Pterodactyl\Exceptions\Service\Deployment\NoViableNodeException
diff --git a/app/Services/Eggs/EggCreationService.php b/app/Services/Eggs/EggCreationService.php
index aaf9823f..45fa8895 100644
--- a/app/Services/Eggs/EggCreationService.php
+++ b/app/Services/Eggs/EggCreationService.php
@@ -15,7 +15,7 @@ use Pterodactyl\Contracts\Repository\EggRepositoryInterface;
 use Illuminate\Contracts\Config\Repository as ConfigRepository;
 use Pterodactyl\Exceptions\Service\Egg\NoParentConfigurationFoundException;
 
-// When a mommy and a daddy pterodactyl really like eachother...
+// When a mommy and a daddy pterodactyl really like each other...
 class EggCreationService
 {
     /**
diff --git a/app/Services/Eggs/Scripts/InstallScriptService.php b/app/Services/Eggs/Scripts/InstallScriptService.php
index 0d9e66bc..b71c10d8 100644
--- a/app/Services/Eggs/Scripts/InstallScriptService.php
+++ b/app/Services/Eggs/Scripts/InstallScriptService.php
@@ -47,7 +47,7 @@ class InstallScriptService
         }
 
         if (! is_null(array_get($data, 'copy_script_from'))) {
-            if (! $this->repository->isCopiableScript(array_get($data, 'copy_script_from'), $egg->nest_id)) {
+            if (! $this->repository->isCopyableScript(array_get($data, 'copy_script_from'), $egg->nest_id)) {
                 throw new InvalidCopyFromException(trans('exceptions.nest.egg.invalid_copy_id'));
             }
         }
diff --git a/app/Services/Servers/StartupCommandViewService.php b/app/Services/Servers/StartupCommandViewService.php
index 7895ec6d..d3cda314 100644
--- a/app/Services/Servers/StartupCommandViewService.php
+++ b/app/Services/Servers/StartupCommandViewService.php
@@ -24,7 +24,7 @@ class StartupCommandViewService
 
     /**
      * Generate a startup command for a server and return all of the user-viewable variables
-     * as well as thier assigned values.
+     * as well as their assigned values.
      *
      * @param int $server
      * @return \Illuminate\Support\Collection
diff --git a/app/Services/Servers/VariableValidatorService.php b/app/Services/Servers/VariableValidatorService.php
index 43685caf..75846055 100644
--- a/app/Services/Servers/VariableValidatorService.php
+++ b/app/Services/Servers/VariableValidatorService.php
@@ -63,7 +63,7 @@ class VariableValidatorService
     }
 
     /**
-     * Validate all of the passed data aganist the given service option variables.
+     * Validate all of the passed data against the given service option variables.
      *
      * @param int   $egg
      * @param array $fields
diff --git a/app/Services/Sftp/AuthenticateUsingPasswordService.php b/app/Services/Sftp/AuthenticateUsingPasswordService.php
index f89a32c5..69057392 100644
--- a/app/Services/Sftp/AuthenticateUsingPasswordService.php
+++ b/app/Services/Sftp/AuthenticateUsingPasswordService.php
@@ -52,7 +52,7 @@ class AuthenticateUsingPasswordService
     }
 
     /**
-     * Attempt to authenticate a provded username and password and determine if they
+     * Attempt to authenticate a provided username and password and determine if they
      * have permission to access a given server. This function does not account for
      * subusers currently. Only administrators and server owners can login to access
      * their files at this time.
diff --git a/app/Services/Users/UserUpdateService.php b/app/Services/Users/UserUpdateService.php
index 440ab57c..440f8b45 100644
--- a/app/Services/Users/UserUpdateService.php
+++ b/app/Services/Users/UserUpdateService.php
@@ -47,7 +47,7 @@ class UserUpdateService
 
     /**
      * Update the user model instance. If the user has been removed as an administrator
-     * revoke all of the authentication tokens that have beenn assigned to their account.
+     * revoke all of the authentication tokens that have been assigned to their account.
      *
      * @param \Pterodactyl\Models\User $user
      * @param array                    $data
diff --git a/tests/Unit/Helpers/HumanReadableTest.php b/tests/Unit/Helpers/HumanReadableTest.php
index 92af8f70..4e46cad3 100644
--- a/tests/Unit/Helpers/HumanReadableTest.php
+++ b/tests/Unit/Helpers/HumanReadableTest.php
@@ -24,7 +24,7 @@ class HumanReadableTest extends TestCase
     }
 
     /**
-     * Provide data to test aganist the helper function.
+     * Provide data to test against the helper function.
      *
      * @return array
      */
diff --git a/tests/Unit/Helpers/IsDigitTest.php b/tests/Unit/Helpers/IsDigitTest.php
index bf445688..6dcef9e2 100644
--- a/tests/Unit/Helpers/IsDigitTest.php
+++ b/tests/Unit/Helpers/IsDigitTest.php
@@ -24,7 +24,7 @@ class IsDigitTest extends TestCase
     }
 
     /**
-     * Provide data to test aganist the helper function.
+     * Provide data to test against the helper function.
      *
      * @return array
      */
diff --git a/tests/Unit/Services/Acl/Api/AdminAclTest.php b/tests/Unit/Services/Acl/Api/AdminAclTest.php
index 2f2f0764..325af82c 100644
--- a/tests/Unit/Services/Acl/Api/AdminAclTest.php
+++ b/tests/Unit/Services/Acl/Api/AdminAclTest.php
@@ -19,7 +19,7 @@ class AdminAclTest extends TestCase
     }
 
     /**
-     * Test that checking aganist a model works as expected.
+     * Test that checking against a model works as expected.
      */
     public function testCheck()
     {
diff --git a/tests/Unit/Services/Eggs/Variables/VariableCreationServiceTest.php b/tests/Unit/Services/Eggs/Variables/VariableCreationServiceTest.php
index 225c9c8e..dd80b9f2 100644
--- a/tests/Unit/Services/Eggs/Variables/VariableCreationServiceTest.php
+++ b/tests/Unit/Services/Eggs/Variables/VariableCreationServiceTest.php
@@ -68,7 +68,7 @@ class VariableCreationServiceTest extends TestCase
 
     /**
      * Test that an empty (null) value passed in the option key is handled
-     * properly as an array. Also tests the same case aganist the default_value.
+     * properly as an array. Also tests the same case against the default_value.
      *
      * @see https://github.com/Pterodactyl/Panel/issues/841
      * @see https://github.com/Pterodactyl/Panel/issues/943
diff --git a/tests/Unit/Services/Packs/PackCreationServiceTest.php b/tests/Unit/Services/Packs/PackCreationServiceTest.php
index d0baddf3..fdf2c503 100644
--- a/tests/Unit/Services/Packs/PackCreationServiceTest.php
+++ b/tests/Unit/Services/Packs/PackCreationServiceTest.php
@@ -154,7 +154,7 @@ class PackCreationServiceTest extends TestCase
     }
 
     /**
-     * Return an array of valid mimetypes to test aganist.
+     * Return an array of valid mimetypes to test against.
      *
      * @return array
      */
@@ -167,7 +167,7 @@ class PackCreationServiceTest extends TestCase
     }
 
     /**
-     * Provide invalid mimetypes to test exceptions aganist.
+     * Provide invalid mimetypes to test exceptions against.
      *
      * @return array
      */
diff --git a/tests/Unit/Services/Schedules/Tasks/TaskCreationServiceTest.php b/tests/Unit/Services/Schedules/Tasks/TaskCreationServiceTest.php
index af517b7e..9993e449 100644
--- a/tests/Unit/Services/Schedules/Tasks/TaskCreationServiceTest.php
+++ b/tests/Unit/Services/Schedules/Tasks/TaskCreationServiceTest.php
@@ -190,7 +190,7 @@ class TaskCreationServiceTest extends TestCase
     }
 
     /**
-     * Return an array of invalid schedule data to test aganist.
+     * Return an array of invalid schedule data to test against.
      *
      * @return array
      */
diff --git a/tests/Unit/Services/Eggs/Scripts/InstallScriptServiceTest.php b/tests/Unit/Services/Eggs/Scripts/InstallScriptServiceTest.php
index 0bb9e780..5070fe33 100644
--- a/tests/Unit/Services/Eggs/Scripts/InstallScriptServiceTest.php
+++ b/tests/Unit/Services/Eggs/Scripts/InstallScriptServiceTest.php
@@ -65,7 +65,7 @@ class InstallScriptServiceTest extends TestCase
     {
         $this->data['copy_script_from'] = 1;
 
-        $this->repository->shouldReceive('isCopiableScript')->with(1, $this->model->nest_id)->once()->andReturn(true);
+        $this->repository->shouldReceive('isCopyableScript')->with(1, $this->model->nest_id)->once()->andReturn(true);
         $this->repository->shouldReceive('withoutFreshModel')->withNoArgs()->once()->andReturnSelf()
             ->shouldReceive('update')->with($this->model->id, $this->data)->andReturnNull();
 
@@ -73,13 +73,13 @@ class InstallScriptServiceTest extends TestCase
     }
 
     /**
      * Test that an exception gets raised when the script is not copiable.
      */
     public function testUpdateWithInvalidCopyScriptFromAttribute()
     {
         $this->data['copy_script_from'] = 1;
 
-        $this->repository->shouldReceive('isCopiableScript')->with(1, $this->model->nest_id)->once()->andReturn(false);
+        $this->repository->shouldReceive('isCopyableScript')->with(1, $this->model->nest_id)->once()->andReturn(false);
         try {
             $this->service->handle($this->model, $this->data);
         } catch (Exception $exception) {
@@ -73,13 +73,13 @@ class InstallScriptServiceTest extends TestCase
 
     /**
-     * Test that an exception gets raised when the script is not copiable.
+     * Test that an exception gets raised when the script is not copyable.
      */
     public function testUpdateWithInvalidCopyScriptFromAttribute()